WebSocketStream

Struct WebSocketStream 

pub struct WebSocketStream<S> { /* private fields */ }
A WebSocket stream that works with compio.

Implementations

Source

impl<S> WebSocketStream<S>
where S: AsyncRead + AsyncWrite,

pub async fn from_raw_socket( stream: S, role: Role, config: impl Into<Config>, ) -> Self

Convert a raw socket into a WebSocketStream without performing a handshake.

disable_nagle will be ignored since the socket is already connected and the user can set nodelay on the socket directly before calling this function if needed.

pub async fn from_partially_read( stream: S, part: Vec<u8>, role: Role, config: impl Into<Config>, ) -> Self

Convert a raw socket into a WebSocketStream without performing a handshake.

disable_nagle will be ignored since the socket is already connected and the user can set nodelay on the socket directly before calling this function if needed.

pub async fn send(&mut self, message: Message) -> Result<(), WsError>

Send a message on the WebSocket stream.

pub async fn read(&mut self) -> Result<Message, WsError>

Read a message from the WebSocket stream.

pub async fn flush(&mut self) -> Result<(), WsError>

Flush the WebSocket stream.

pub async fn close( &mut self, close_frame: Option<CloseFrame>, ) -> Result<(), WsError>

Close the WebSocket connection.

pub fn get_ref(&self) -> &S

Get a reference to the underlying stream.

pub fn get_mut(&mut self) -> &mut S

Get a mutable reference to the underlying stream.